package com.pnkx.framework.notify.impl;

import com.pnkx.common.core.controller.BaseController;
import com.pnkx.framework.notify.NotifyStrategy;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.nio.charset.StandardCharsets;

/**
 * FeishuNotifyStrategy
 *
 * @author 裴浩宇
 * @version 1.0
 * @date 2024/4/30 17:04
 * @description 飞书通知
 */
@Component
public class FeishuNotifyStrategy implements NotifyStrategy {

    protected final Logger logger = LoggerFactory.getLogger(FeishuNotifyStrategy.class);

    @Value("${feishu.webhook.url}")
    private String webhookUrl;

    @Override
    public void sendNotification(String recipient, String message) {
        try {
            URL url = new URL(webhookUrl);
            HttpURLConnection connection = getHttpURLConnection(message, url);

            int responseCode = connection.getResponseCode();
            if (responseCode == HttpURLConnection.HTTP_OK) {
                logger.info("飞书通知成功");
            } else {
                logger.error("飞书通知失败，响应码：{}", responseCode);
            }

        } catch (Exception e) {
            logger.error("发送飞书通知时发生错误：{}", e.getMessage());
        }
    }

    /**
     * 获取HttpURLConnection
     * @param message 通知内容
     * @param url webhook地址
     * @return HttpURLConnection
     * @throws IOException 异常
     */
    private static HttpURLConnection getHttpURLConnection(String message, URL url) throws IOException {
        HttpURLConnection connection = (HttpURLConnection) url.openConnection();
        connection.setRequestMethod("POST");
        connection.setRequestProperty("Content-Type", "application/json; charset=utf-8");
        connection.setDoOutput(true);

        String jsonInputString = "{\"msg_type\":\"text\",\"content\":{\"text\":\"" + message + "\"}}";

        try (OutputStream os = connection.getOutputStream()) {
            byte[] input = jsonInputString.getBytes(StandardCharsets.UTF_8);
            os.write(input, 0, input.length);
        }
        return connection;
    }
}
